@@ -191,15 +191,37 @@ function delete_category($id) {
 	// delete products in this category that also belong
 	// to the parent category, to avoid duplicates forbidden
 	// by the primary key constraint
+/* Nested queries aren't still supported by MySQL :(
+ *	$qid = db_query("
+ *		DELETE FROM products_categories WHERE ( product_id,category_id ) IN (
+ *			SELECT * FROM products_categories pc WHERE category_id = '$id' AND
+ *			EXISTS (
+ *				SELECT * FROM products_categories
+ *				WHERE product_id = pc.product_id
+ *					AND category_id = '$cat->parent_id'
+ *			)
+ *		)
+ *	");
+ * a workaround in the following */
 	$qid = db_query("
-		DELETE FROM products_categories WHERE ( product_id,category_id ) IN (
-			SELECT * FROM products_categories pc WHERE category_id = '$id' AND
-			EXISTS (
-				SELECT * FROM products_categories
-				WHERE product_id = pc.product_id
-					AND category_id = '$cat->parent_id'
-			)
-		)
+		SELECT pc1.product_id
+		FROM products_categories pc1 , products_categories pc2
+		WHERE
+			pc1.product_id = pc2.product_id
+			AND pc1.category_id = '$cat->parent_id'
+			AND pc2.category_id = '$id'
+	");
+	$numr = db_num_rows($qid);
+	$toberemoved = "";
+	for ($i=0; $i<$numr-1; $i++) {
+		$appoggio = db_fetch_object($qid, $i);
+		$toberemoved .= "'" . $appoggio->product_id . "', ";
+	}
+	$appoggio = db_fetch_object($qid, $numr-1);
+	$toberemoved .= "'" . $appoggio->product_id . "'";
+	$qid = db_query("
+		DELETE FROM products_categories
+		WHERE category_id = '$id' AND product_id IN ($toberemoved)
 	");
 
 	/* re-assign all the products in this category to the parent category */
@@ -229,6 +251,9 @@ function insert_subcategory($id, $frm) {
 	global $SESSION;
 	include ($CFG->global);
 
+	while (list($key, $val) = each($frm)){
+		if (is_string($val)) $frm[$key] = addslashes($val);
+	}
 	$qid = db_query("
 	INSERT INTO categories (parent_id, name, on_special, description)
 	VALUES ('$frm[parent]', '$frm[name]', '$frm[on_special]', '$frm[description]')
@@ -245,6 +270,9 @@ function update_category($id, $frm) {
 	global $SESSION;
 	include ($CFG->global);
 
+	while (list($key, $val) = each($frm)){
+		if (is_string($val)) $frm[$key] = addslashes($val);
+	}
 	$qid = db_query("
 	UPDATE categories SET
 		 parent_id = '$frm[parent]'
@@ -319,6 +347,8 @@ function import_category($userfile) {
 	$fcontents = file ($userfile);
 	/* Traverse the file */
 	while (list ($line_num, $line) = each ($fcontents)) {
+		// Microsoft Stupidity Suppression
+		$line = ereg_replace(chr(13), "", $line);
 //		$fldarr = split("\",\"",ereg_replace("^\"|\"..$|\".$","",$line));
 		$fldarr = split("\t",ereg_replace("\n$","",$line));
 		/* Empty parent = "Top" */
