@@ -142,8 +142,8 @@ $Extended_Description = "Descrizione estesa";
 $Discount = "Sconto";
 $Starting_from = "a partire da";
 $C_Add_Category = "[+C] Aggiungi categoria";
-$C_Add_Brand = "[+C] Aggiungi marca";
-$C_Add_IVA = "[+C] Aggiungi percentuale IVA";
+$C_Add_Brand = "[+M] Aggiungi marca";
+$C_Add_IVA = "[+I] Aggiungi percentuale IVA";
 $C_Add_Product = "[+P] Aggiungi prodotto";
 $Action = "Azione";
 $User = "Utente";
