@@ -142,8 +142,8 @@ $Extended_Description = "Extended Description";
 $Discount = "Discount";
 $Starting_from = "starting from";
 $C_Add_Category = "[+C] Add Category";
-$C_Add_Brand = "[+C] Add Brand";
-$C_Add_IVA = "[+C] Add IVA percentual";
+$C_Add_Brand = "[+B] Add Brand";
+$C_Add_IVA = "[+I] Add IVA percentual";
 $C_Add_Product = "[+P] Add Product";
 $Action = "Action";
 $User = "User";
